<h1 align="center">
aeolus
</h1>
<h4 align="center">
Python library for the analysis and visualisation of climate model output, primarily the UK Met Office models.
</h4>

<p align="center">
<a href="https://www.python.org/downloads/">
<img src="https://img.shields.io/badge/python-3.10+-blue.svg?logo=python&logoColor=white"
     alt="Python 3.10+"></a>
<a href="https://exoclim.github.io/aeolus">
<img src="https://img.shields.io/badge/docs-latest-green?logo=github"
     alt="Documentation"></a>
<a href="https://github.com/exoclim/aeolus/actions?query=workflow%3Atests">
<img src="https://github.com/exoclim/aeolus/workflows/tests/badge.svg"
     alt="Tests"></a>
<a href="https://codecov.io/github/exoclim/aeolus?branch=main">
<img src="https://codecov.io/github/exoclim/aeolus/coverage.svg?branch=main"
     alt="Coverage"></a>
<a href="https://anaconda.org/conda-forge/aeolus">
<img src="https://img.shields.io/conda/vn/conda-forge/aeolus.svg"
     alt="Conda Version"></a>
<a href="https://pypi.org/project/aeolus/">
<img src="https://img.shields.io/pypi/v/aeolus.svg?logo=pypi&logoColor=white"
     alt="PyPI"></a>
<a href="LICENSE">
<img src="https://img.shields.io/badge/license-LGPL%20v3-blue.svg?logo=gnu"
     alt="License: LGPL v3"></a>
<a href="https://github.com/psf/black">
<img src="https://img.shields.io/badge/code%20style-black-000000.svg"
     alt="black"></a>
<a href="https://results.pre-commit.ci/latest/github/exoclim/aeolus/main">
<img src="https://results.pre-commit.ci/badge/github/exoclim/aeolus/main.svg"
     alt="pre-commit.ci status"></a>
<a href="https://zenodo.org/badge/latestdoi/173159428">
<img src="https://zenodo.org/badge/173159428.svg"
     alt="DOI"></a>
</p>

<p align="center">
It leverages the functionality of <a href=https://github.com/SciTools/iris>iris</a> and has modules geared towards working with 3D general circulation models of planetary atmospheres.
The documentation is available <a href=https://exoclim.github.io/aeolus>here</a>.
<a href=https://exoclim.github.io/aeolus/contributing.html>Contributions</a> are very welcome.
</p>
